#[non_exhaustive]pub struct Config {
pub ignore: Vec<String>,
pub only: Vec<String>,
pub equiv: Vec<(String, String)>,
pub wild_defaults: bool,
pub coverage: bool,
pub display_names: Vec<String>,
pub references: Vec<PathBuf>,
pub colour: Colour,
pub file: PathBuf,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ignore: Vec<String>Keys to ignore.
only: Vec<String>Show only the specified keys.
equiv: Vec<(String, String)>Treat the sections with the specified names as equivalent. e.g. “.got.plt=.got”
wild_defaults: boolApply defaults for things that should be ignored currently for Wild. These defaults are subject to change as Wild changes.
coverage: boolPrint information about what sections did and didn’t get diffed.
display_names: Vec<String>Display names for input files.
references: Vec<PathBuf>Files to compare against
colour: Colourfile: PathBufPrimary file that we’re validating against the reference file(s)
Implementations